#
# spec file for package python-pyfakefs
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyfakefs
Version:        3.5.8
Release:        2.1
Summary:        Fake file system that mocks the Python file system modules
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://pyfakefs.org
Source:         https://github.com/jmcgeheeiv/pyfakefs/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module pathlib2 >= 2.3.2}
BuildRequires:  %{python_module pytest >= 2.8.6}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-scandir >= 1.8
Requires:       python-pathlib2 >= 2.3.2
BuildArch:      noarch
%ifpython2
Requires:       python-scandir >= 1.8
%endif
%python_subpackages

%description
pyfakefs implements a fake file system that mocks the Python file system
modules. Using pyfakefs, your tests operate on a fake file system in
memory without touching the real disk. The software under test requires
no modification to work with pyfakefs.

%prep
%setup -q -n pyfakefs-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand rm -rf %{buildroot}%{$python_sitelib}/pyfakefs/tests/

%check
export LANG=C.UTF-8
%python_exec setup.py test

%files %{python_files}
%doc CHANGES* README*
%license COPYING*
%{python_sitelib}/*

%changelog
* Fri Mar 22 2019 tchvatal@suse.com
- Update to 3.5.8:
  * Mainly fixes a regression bug under Python 2.7.
* Tue Feb 12 2019 kbabioch@suse.de
- Update to version 3.5.7
  * Fixes a regression introduced in the last version
* Mon Jan 14 2019 kbabioch@suse.de
- Removed unit tests from package
* Sun Jan 13 2019 kbabioch@suse.de
- Update to version 3.5.6
  * import external pathlib2 and scandir packages first if present
* Thu Dec 20 2018 kbabioch@suse.de
- Update to version 3.5.5
  * Removed permission warnings (shebang line vs. executable bit)
* Thu Dec 20 2018 kbabioch@suse.de
- Update to version 3.5.4
  * added context manager class Pause for pause/resume
  * fixed permission handling for root user
  * avoid AttributeError triggered by modules without __module__ attribute
* Thu Nov 22 2018 kbabioch@suse.de
- Update to version 3.5.3
  * automatically patch file system methods imported as another name like from
    os.path import exists as my_exists, including builtin open and io.open
  * make tests for access time less strict to account for file systems that do
    not change it immediately
* Mon Nov 12 2018 kbabioch@suse.com
- Update to version 3.5.2
  * This is mostly a bug-fix release.
  * added support for pause/resume of patching the file system modules
  * allow to set current group ID, set current user ID and group ID as `st_uid`
    and `st_gid` in new files
  * fixed using `modules_to_patch` (regression)
  * fixed recursion error on unpickling the fake file system
  * allow trailing path in `add_real_directory`
* Thu Nov  1 2018 tchvatal@suse.com
- State in more dependencies, the tests are still borked
* Tue Oct 23 2018 kbabioch@suse.com
- Update to version 3.5
  * This version of pyfakefs does not support Python 3.3.
  * The deprecation warnings for the old API are now switched on by default.
  * Improved automatic patching:
  * added possibility to set user ID
  * added side_effect option to fake files
  * added some support for extended filesystem attributes under Linux
  * handle `contents=None` in `create_file()` as empty contents if size not set
  * added pathlib2 support
  * added support for null device
  * improved error message for "Bad file descriptor in fake filesystem"
  * fixed pytest when both pyfakefs and future are installed
  * file timestamps are now updated more according to the real behavior
  * fixed a problem related with patching shutil functions using zipfile
* Thu Jun 14 2018 kbabioch@suse.com
- Update to version 3.4.3
  - Added support for path-like objects as arguments in create_file(),
    create_dir(), create_symlink(), add_real_file() and add_real_directory()
  - Bugfixes:
  - tell after seek gave incorrect result in append mode
  - flushing file contents after truncate was incorrect under some conditions
  - readline() did not work correctly in binary mode
  - pathlib.Path.resolve() behaved incorrectly if the path does not exist
  - closed attribute was not implemented in fake file
  - add_real_directory did not behave correctly for nested paths
  - several functions did not behave correctly for paths ending with a
    path separator
* Tue Apr 17 2018 kbabioch@suse.com
- Initial packaging of version 3.4.1
